package com.four.patient.controller;


import com.alibaba.fastjson.JSONObject;
import com.four.common.core.domain.Result;
import com.four.common.duck.communitypatients.SymptomsDrugs;
import com.four.common.duck.response.ResponseRegistrationInformation;
import com.four.patient.service.RegistrationInformationService;
import com.four.system.api.domain.SysDoctor;
import com.four.system.api.domain.SysRegistrationInformation;
import lombok.extern.log4j.Log4j2;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletRequest;
import java.util.List;


@RestController
@RequestMapping("/registration")
@Log4j2
public class RegistrationInformationController {

    @Autowired
    private RegistrationInformationService registrationInformationService;

    @Autowired
    private HttpServletRequest request;



    /**
     * 查询全部科室
     * @return
     */
    @GetMapping("/ShowSymptomsDrug")
    public Result<List<SymptomsDrugs>> ShowSymptomsDrug(){
        log.info("功能名称:查询全部科室,请求URI:{},请求方法:{}",request.getRequestURI(),
                request.getMethod());
        List<SymptomsDrugs> list=registrationInformationService.ShowSymptomsDrug();
        log.info("功能名称:查询全部科室,请求URI:{},请求方法:{},返回结果:{}",request.getRequestURI(),
                request.getMethod(),JSONObject.toJSONString(list));
        return Result.success(list);
    }

    /**
     * 查询不同科室价格倒序的医生信息
     * @param medicalDepartmentId
     * @return
     */
    @PostMapping("/ShowRegistrationInformationAllPrice")
    public Result<List<SysDoctor>> ShowRegistrationInformationAllPrice(@RequestParam Long medicalDepartmentId){
        log.info("功能名称:查询价格倒序的医生信息,请求URI:{},请求方法:{},请求参数:{}",request.getRequestURI(),
                request.getMethod(),JSONObject.toJSONString(medicalDepartmentId));
        List<SysDoctor> list=registrationInformationService.ShowRegistrationInformationAllPrice(medicalDepartmentId);
        log.info("功能名称:查询价格倒序的医生信息,请求URI:{},请求方法:{},请求参数:{}",request.getRequestURI(),
                request.getMethod(),JSONObject.toJSONString(list));
        return Result.success(list,"查询成功");
    }


    /**
     * 查询不同科室接待患者人数倒序的医生信息
     * @param medicalDepartmentId
     * @return
     */
    @PostMapping("/ShowRegistrationInformationNumber")
    public Result<List<SysDoctor>> ShowRegistrationInformationNumber(@RequestParam Long medicalDepartmentId){
        log.info("功能名称:查询不同科室接待患者人数倒序医生信息,请求URI:{},请求方法:{},请求参数:{}",request.getRequestURI(),
                request.getMethod(),JSONObject.toJSONString(medicalDepartmentId));
        List<SysDoctor> sysDoctorList=registrationInformationService.ShowRegistrationInformationNumber(medicalDepartmentId);
        log.info("功能名称:查询不同科室接待患者人数倒序医生信息,请求URI:{},请求方法:{},返回结果:{}",request.getRequestURI(),
                request.getMethod(),JSONObject.toJSONString(sysDoctorList));
        return Result.success(sysDoctorList,"查询成功");
    }


    /**
     * 查询不同科室好评人数倒序排序的医生信息
     * @param medicalDepartmentId
     * @return
     */
    @PostMapping("/ShowRegistrationInformationPraise")
    public Result<List<SysDoctor>> ShowRegistrationInformationPraise(@RequestParam Long medicalDepartmentId){
        log.info("功能名称:查询不同科室好评人数倒序医生信息,请求URI:{},请求方法:{},请求参数:{}",request.getRequestURI(),
                request.getMethod(),JSONObject.toJSONString(medicalDepartmentId));
        List<SysDoctor> list=registrationInformationService.ShowRegistrationInformationPraise(medicalDepartmentId);
        log.info("功能名称:查询不同科室好评人数倒序医生信息,请求URI:{},请求方法:{},返回结果:{}",request.getRequestURI(),
                request.getMethod(),JSONObject.toJSONString(list));
        return Result.success(list,"查询成功");
    }


    /**
     * 查询不同科室综合排序医生信息
     * @param medicalDepartmentId
     * @return
     */
    @PostMapping("/ShowRegistrationInformationAll")
    public Result<List<SysDoctor>> ShowRegistrationInformationAll(@RequestParam Long medicalDepartmentId){
        log.info("功能名称:查询不同科室综合排序医生信息,请求URI:{},请求方法:{},请求参数:{}",request.getRequestURI(),
                request.getMethod(),JSONObject.toJSONString(medicalDepartmentId));
        List<SysDoctor> list=registrationInformationService.ShowRegistrationInformationAll(medicalDepartmentId);
        log.info("功能名称:查询不同科室综合排序医生信息,请求URI:{},请求方法:{},请求参数:{}",request.getRequestURI(),
                request.getMethod(),JSONObject.toJSONString(list));
        return Result.success(list,"查询成功");
    }



    /**
     * 查看医生详情
     * @param registrationInformationId
     * @return
     */
    @PostMapping("/ShowRegistration")
    public Result<SysRegistrationInformation> ShowRegistration(@RequestParam Long registrationInformationId){
        log.info("功能名称:查询医生详情,请求URI:{},请求方法:{},请求参数:{}",request.getRequestURI(),
                request.getMethod(),JSONObject.toJSONString(registrationInformationId));
        SysRegistrationInformation registrationInformation=registrationInformationService.ShowRegistration(registrationInformationId);
        log.info("功能名称:查询医生详情,请求URI:{},请求方法:{},返回结果:{}",request.getRequestURI(),
                request.getMethod(),JSONObject.toJSONString(registrationInformation));
        return Result.success(registrationInformation,"查询成功");
    }
}
