package com.four.patient.feign;

import com.four.common.core.domain.R;
import com.four.common.core.web.domain.AjaxResult;
import com.four.system.api.domain.SysDoctor;
import com.four.system.api.domain.SysUser;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import java.math.BigDecimal;


public interface DoctorFeign {
    /**
     * 查询综合排序倒序医生信息
     * @param medicalDepartmentId
     * @author 李闯
     * @return
     */
    @PostMapping("/user/findDoctorComprehensive/{medicalDepartmentId}")
    public AjaxResult findDoctorComprehensive(@PathVariable(value = "medicalDepartmentId") Long medicalDepartmentId);

    /**
     * 查询好评人数倒序的医生信息
     * @param medicalDepartmentId;
     * @author 李闯
     * @return
     */
    @PostMapping("/user/findDoctorNumber/{medicalDepartmentId}")
    public AjaxResult findDoctorNumber(@PathVariable(value = "medicalDepartmentId") Long medicalDepartmentId);

    /**
     * 查询接待患者人数倒序排序医生信息
     * @param medicalDepartmentId
     * @author 李闯
     * @return
     */
    @PostMapping("/user/findDoctorPraise/{medicalDepartmentId}")
    public AjaxResult findDoctorPraise(@PathVariable(value = "medicalDepartmentId") Long medicalDepartmentId);

    /**
     * 查询价格倒序的医生信息
     * @param medicalDepartmentId
     * @author 李闯
     * @return
     */
    @PostMapping("/user/findDoctorInformation/{medicalDepartmentId}")
    public AjaxResult findDoctorInformation(@PathVariable(value = "medicalDepartmentId") Long medicalDepartmentId);


    /**
     * 根据userId来查询用户信息
     * @param userId
     * @author 李闯
     * @return
     */
    @GetMapping("/user/findByUserId/{userId}")
    public R<SysUser> findByUserId(@PathVariable(value = "userId") Long userId);


    /**
     * 根据registrationInformationId
     * 来查询医生注册信息
     * @param registrationInformationId
     * @author 李闯
     * @return
     */
    @GetMapping("/user/findRegistrationInfoUserId/{registrationInformationId}")
    public R<SysDoctor> findRegistrationInfoUserId(@PathVariable("registrationInformationId") Long registrationInformationId);

    /**
     * 根据用户Id修改用户余额
     * @param userId
     * @param userMoney
     * @author 李闯
     * @return
     */
    @PostMapping("/user/updateSysUserMoney/{userId}/{userMoney}")
    public AjaxResult updateSysUserMoney(@PathVariable("userId") Long userId, @PathVariable("userMoney") BigDecimal userMoney);

    /**
     * 查询医生详情信息
     * @param registrationInformationId
     * @author 李闯
     * @ruturn
     */
    @GetMapping("/user/findRegistrationInformation/{registrationInformationId}")
    public AjaxResult findRegistrationInformation(@PathVariable("registrationInformationId") Long registrationInformationId);
}
