package com.four.patient.service.Impl;

import com.four.common.core.domain.R;
import com.four.common.duck.interrogation.HistoricalConsultation;
import com.four.common.duck.interrogation.RegistrationInformation;
import com.four.common.duck.my.User;
import com.four.common.security.utils.SecurityUtils;
import com.four.patient.feign.DoctorFeign;
import com.four.patient.mapper.GiftMapper;
import com.four.patient.mapper.HistoricalConsultationMapper;
import com.four.patient.service.HistoricalConsultationService;
import com.four.system.api.domain.SysDoctor;
import com.four.system.api.domain.SysUser;
import com.four.system.api.model.LoginUser;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.math.BigDecimal;
import java.util.List;

@Service
public class HistoricalConsultationServiceImpl implements HistoricalConsultationService{

    @Autowired
    private HistoricalConsultationMapper historicalConsultationMapper;
    @Autowired
    private DoctorFeign doctorFeign;

    @Transactional
    @Override
    public Integer insertHistoricalConsultation(HistoricalConsultation historicalConsultation) {
        Integer i=historicalConsultationMapper.insertHistoricalConsultation(historicalConsultation);
        if (i<0){
            return null;
        }
        //获取患者id
        LoginUser loginUser = SecurityUtils.getLoginUser();
        historicalConsultation.setPatientId(loginUser.getUserid());
        //获取患者金额
        R<SysUser> sysUserR = doctorFeign.findByUserId(loginUser.getUserid());
        SysUser sysUser = sysUserR.getData();
        double userMoney = sysUser.getUserMoney().doubleValue();
        //获取医生信息
        R<SysDoctor> registrationInfoUserId = doctorFeign.findRegistrationInfoUserId(historicalConsultation.getRegistrationInformationId());
        SysDoctor sysDoctor = registrationInfoUserId.getData();
        //获取医生诊金
        double consultPrice = sysDoctor.getConsultingPrice().doubleValue();
        //获取用户结清诊金后余额
        double patientMoney=(userMoney-consultPrice);
        doctorFeign.updateSysUserMoney(sysUser.getUserId(),BigDecimal.valueOf(patientMoney));
        //获取医生的用户信息
        R<SysUser> byUserId = doctorFeign.findByUserId(sysDoctor.getUserId());
        SysUser user = byUserId.getData();
        //医生问诊后的余额
        Double doctorPrice=(user.getUserMoney().doubleValue() + consultPrice);
        doctorFeign.updateSysUserMoney(user.getUserId(),BigDecimal.valueOf(doctorPrice));
        return i;
    }

    @Override
    public List<HistoricalConsultation> ShowHistoricalConsultation() {
        List<HistoricalConsultation> historicalConsultationList=historicalConsultationMapper.ShowHistoricalConsultation();
        return historicalConsultationList;
    }

    @Override
    public Integer updateHisorical(Long historicalConsultationId) {
        Integer i=historicalConsultationMapper.updateHisorical(historicalConsultationId);
        if (i<0){
            return null;
        }
        return i;
    }
}
